URL schemes expose an attack surface that can be triggered by visiting a malicious website in Safari or from a malicious
application. Therefore, it is important that the application validates parameters and restricts actions permitted from
the URL scheme.
